#[non_exhaustive]pub struct ExportDataRequest {
pub name: String,
pub request_id: String,
pub service_account: String,
pub source: Option<Source>,
pub destination: Option<Destination>,
/* private fields */
}Expand description
Export data from Managed Lustre to a Cloud Storage bucket.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the Managed Lustre instance in the format
projects/{project}/locations/{location}/instances/{instance}.
request_id: StringOptional. UUID to identify requests.
service_account: StringOptional. User-specified service account used to perform the transfer. If unspecified, the Managed Lustre service agent is used.
source: Option<Source>The source of the data transfer.
destination: Option<Destination>The destination of the data transfer.
Implementations
Sourceimpl ExportDataRequest
impl ExportDataRequest
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of service_account.
Example
let x = ExportDataRequest::new().set_service_account("example");Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
use google_cloud_lustre_v1::model::LustrePath;
let x = ExportDataRequest::new().set_source(Some(
google_cloud_lustre_v1::model::export_data_request::Source::LustrePath(LustrePath::default().into())));Sourcepub fn lustre_path(&self) -> Option<&Box<LustrePath>>
pub fn lustre_path(&self) -> Option<&Box<LustrePath>>
The value of source
if it holds a LustrePath, None if the field is not set or
holds a different branch.
Sourcepub fn set_lustre_path<T: Into<Box<LustrePath>>>(self, v: T) -> Self
pub fn set_lustre_path<T: Into<Box<LustrePath>>>(self, v: T) -> Self
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
use google_cloud_lustre_v1::model::GcsPath;
let x = ExportDataRequest::new().set_destination(Some(
google_cloud_lustre_v1::model::export_data_request::Destination::GcsPath(GcsPath::default().into())));Sourcepub fn gcs_path(&self) -> Option<&Box<GcsPath>>
pub fn gcs_path(&self) -> Option<&Box<GcsPath>>
The value of destination
if it holds a GcsPath, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_path<T: Into<Box<GcsPath>>>(self, v: T) -> Self
pub fn set_gcs_path<T: Into<Box<GcsPath>>>(self, v: T) -> Self
Sets the value of destination
to hold a GcsPath.
Note that all the setters affecting destination are
mutually exclusive.
Example
use google_cloud_lustre_v1::model::GcsPath;
let x = ExportDataRequest::new().set_gcs_path(GcsPath::default()/* use setters */);
assert!(x.gcs_path().is_some());Trait Implementations
Sourceimpl Clone for ExportDataRequest
impl Clone for ExportDataRequest
Sourcefn clone(&self) -> ExportDataRequest
fn clone(&self) -> ExportDataRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExportDataRequest
impl Debug for ExportDataRequest
Sourceimpl Default for ExportDataRequest
impl Default for ExportDataRequest
Sourcefn default() -> ExportDataRequest
fn default() -> ExportDataRequest
Sourceimpl Message for ExportDataRequest
impl Message for ExportDataRequest
Sourceimpl PartialEq for ExportDataRequest
impl PartialEq for ExportDataRequest
impl StructuralPartialEq for ExportDataRequest