#[non_exhaustive]pub struct GcsPath {
pub uri: String,
/* private fields */
}Expand description
Specifies a Cloud Storage bucket and, optionally, a path inside the bucket.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringRequired. The URI to a Cloud Storage bucket, or a path within a bucket,
using the format gs://<bucket_name>/<optional_path_inside_bucket>/. If a
path inside the bucket is specified, it must end with a forward slash
(/).
Implementations