#[non_exhaustive]pub struct ImportDataRequest {
pub name: String,
pub request_id: String,
pub service_account: String,
pub source: Option<Source>,
pub destination: Option<Destination>,
/* private fields */
}Expand description
Message for importing data to Lustre.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the Managed Lustre instance in the format
projects/{project}/locations/{location}/instances/{instance}.
request_id: StringOptional. UUID to identify requests.
service_account: StringOptional. User-specified service account used to perform the transfer. If unspecified, the default Managed Lustre service agent will be used.
source: Option<Source>A Cloud Storage URI of a folder to import file data from, in the
form of gs://<bucket_name>/<path_inside_bucket>/.
destination: Option<Destination>The destination of the data transfer.
Implementations
Sourceimpl ImportDataRequest
impl ImportDataRequest
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of service_account.
Example
let x = ImportDataRequest::new().set_service_account("example");Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sourcepub fn gcs_path(&self) -> Option<&Box<GcsPath>>
pub fn gcs_path(&self) -> Option<&Box<GcsPath>>
The value of source
if it holds a GcsPath, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_path<T: Into<Box<GcsPath>>>(self, v: T) -> Self
pub fn set_gcs_path<T: Into<Box<GcsPath>>>(self, v: T) -> Self
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
use google_cloud_lustre_v1::model::LustrePath;
let x = ImportDataRequest::new().set_destination(Some(
google_cloud_lustre_v1::model::import_data_request::Destination::LustrePath(LustrePath::default().into())));Sourcepub fn lustre_path(&self) -> Option<&Box<LustrePath>>
pub fn lustre_path(&self) -> Option<&Box<LustrePath>>
The value of destination
if it holds a LustrePath, None if the field is not set or
holds a different branch.
Sourcepub fn set_lustre_path<T: Into<Box<LustrePath>>>(self, v: T) -> Self
pub fn set_lustre_path<T: Into<Box<LustrePath>>>(self, v: T) -> Self
Sets the value of destination
to hold a LustrePath.
Note that all the setters affecting destination are
mutually exclusive.
Example
use google_cloud_lustre_v1::model::LustrePath;
let x = ImportDataRequest::new().set_lustre_path(LustrePath::default()/* use setters */);
assert!(x.lustre_path().is_some());Trait Implementations
Sourceimpl Clone for ImportDataRequest
impl Clone for ImportDataRequest
Sourcefn clone(&self) -> ImportDataRequest
fn clone(&self) -> ImportDataRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ImportDataRequest
impl Debug for ImportDataRequest
Sourceimpl Default for ImportDataRequest
impl Default for ImportDataRequest
Sourcefn default() -> ImportDataRequest
fn default() -> ImportDataRequest
Sourceimpl Message for ImportDataRequest
impl Message for ImportDataRequest
Sourceimpl PartialEq for ImportDataRequest
impl PartialEq for ImportDataRequest
impl StructuralPartialEq for ImportDataRequest