#[non_exhaustive]pub struct Instance {
pub name: String,
pub filesystem: String,
pub capacity_gib: i64,
pub network: String,
pub state: State,
pub mount_point: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub labels: HashMap<String, String>,
pub per_unit_storage_throughput: i64,
pub gke_support_enabled: bool,
/* private fields */
}Expand description
A Managed Lustre instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the instance.
filesystem: StringRequired. Immutable. The filesystem name for this instance. This name is used by client-side tools, including when mounting the instance. Must be eight characters or less and can only contain letters and numbers.
capacity_gib: i64Required. The storage capacity of the instance in gibibytes (GiB). Allowed
values are from 18000 to 954000, in increments of 9000.
network: StringRequired. Immutable. The full name of the VPC network to which the instance
is connected. Must be in the format
projects/{project_id}/global/networks/{network_name}.
state: StateOutput only. The state of the instance.
mount_point: StringOutput only. Mount point of the instance in the format
IP_ADDRESS@tcp:/FILESYSTEM.
create_time: Option<Timestamp>Output only. Timestamp when the instance was created.
update_time: Option<Timestamp>Output only. Timestamp when the instance was last updated.
description: StringOptional. A user-readable description of the instance.
labels: HashMap<String, String>Optional. Labels as key value pairs.
per_unit_storage_throughput: i64Required. The throughput of the instance in MB/s/TiB. Valid values are 125, 250, 500, 1000.
gke_support_enabled: boolOptional. Indicates whether you want to enable support for GKE clients. By default, GKE clients are not supported. Deprecated. No longer required for GKE instance creation.
Implementations
Sourceimpl Instance
impl Instance
Sourcepub fn set_filesystem<T: Into<String>>(self, v: T) -> Self
pub fn set_filesystem<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_capacity_gib<T: Into<i64>>(self, v: T) -> Self
pub fn set_capacity_gib<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_network<T: Into<String>>(self, v: T) -> Self
pub fn set_network<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_mount_point<T: Into<String>>(self, v: T) -> Self
pub fn set_mount_point<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_per_unit_storage_throughput<T: Into<i64>>(self, v: T) -> Self
pub fn set_per_unit_storage_throughput<T: Into<i64>>(self, v: T) -> Self
Sets the value of per_unit_storage_throughput.
Example
let x = Instance::new().set_per_unit_storage_throughput(42);Sourcepub fn set_gke_support_enabled<T: Into<bool>>(self, v: T) -> Self
👎Deprecated
pub fn set_gke_support_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of gke_support_enabled.
Example
let x = Instance::new().set_gke_support_enabled(true);Trait Implementations
impl StructuralPartialEq for Instance